/////////////////////////////////////////////////////////////////
// Solution_VCDlg.cpp - VC Sample for SBARCO API DLL
//
// Copyright (C) Sbarco Co. Ltd. 2010 - 2012  All rights reserved.
//
// History - 2010/08/09 Ver:1.0 - First Release
//           2010/11/11 Ver:1.1 - Add BarDrawer Functions
//           2010/11/23 Ver:1.2 - Remove the rectangle of PrintImage function. The rectangle is for debuging.
//			 2011/05/26 Ver:1.4 - Fixed bug for Tear-Off Mode of SetAfterPrint Function.
//           2011/06/09 Ver:1.5 - Function of PortOpen added an option of name pipe for sharing printer.
//			 2011/07/04 Ver:1.6 - Add function for SetReferencePoint, GetReferencePoint.
//			 2011/07/25 Ver:1.7 - Modify TPH width from 200 to 203 dpi.
//                              - Fixed USB enum bug for one of longer USB register name.
//                              - Add function for Y offset of TPH.
//           2011/08/31 Ver:1.8 - Add Form Functions for FormSaveByFileA, FormSaveByFileW, FormCheck, FormExecute,
//                              - FormParameterData and FormPrint.
//                              - Add a FormTest sample in VC and VB.
//           2011/09/08 Ver:1.9 - Add Ethernet communication for PortEnumCount(), PortEnumGet() and PortOpen() Functions.
//           2011/10/03 Ver:1.10 - Add Delphi Sample Codes.
//                               - Fixed RS-232 default baud rate value from 115200 to 9600.
//                               - Fixed RS-232 communication bug in Win7
//                               - Fixed GetPrintDistance() bug in Dot Mode.
//                               - Change the DllAbout() return value from integer to double.
//           2011/12/08 Ver:1.11 - OpenPort() removed the query action.
//                               - PrintLabel() add a command for saving data to RAM.
//                               - When the print fails, the program automatically clears the memory of the print content.
//                               - If the program execution path exists file "DLLTOFILE.txt", the program will automatically print the contents to "DLLTOFILE.txt".
//                               - Add ImageSave(), ImagePrint(), ImageDelete() functions for not storing image for many times.
//           2012/02/13 Ver:1.12 - Add PrintTTF_AlignmentA, PrintTTF_AlignmentW for True Type Font Text with horizontal alignment.
//                                 Add PrintParagraphA, PrintParagraphW for True Type Font paragraph with horizontal alignement.
//                                 Add PrintQRcode for QR code.
//                                 Add CShap Sample Codes.



#include "stdafx.h"
#include "Solution_VC.h"
#include "Solution_VCDlg.h"

#include "SDK_API.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif


// CAboutDlg dialog used for App About

class CAboutDlg : public CDialog
{
public:
	CAboutDlg();

// Dialog Data
	enum { IDD = IDD_ABOUTBOX };

	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support

// Implementation
protected:
	DECLARE_MESSAGE_MAP()
};

CAboutDlg::CAboutDlg() : CDialog(CAboutDlg::IDD)
{
}

void CAboutDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
}

BEGIN_MESSAGE_MAP(CAboutDlg, CDialog)
END_MESSAGE_MAP()


// CSolution_VCDlg dialog




CSolution_VCDlg::CSolution_VCDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CSolution_VCDlg::IDD, pParent)
{
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CSolution_VCDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
}

BEGIN_MESSAGE_MAP(CSolution_VCDlg, CDialog)
	ON_WM_SYSCOMMAND()
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	//}}AFX_MSG_MAP
	ON_BN_CLICKED(IDC_BUT_TRUETYPEFONT, OnBnClickedButTruetypefont)
	ON_BN_CLICKED(IDC_BUT_DLL_ABOUT, OnBnClickedButDllAbout)
	ON_BN_CLICKED(IDC_BUT_SETTINGS, OnBnClickedButSettings)	
	ON_BN_CLICKED(IDC_BUT_DEMAND_CALTEST, OnBnClickedButDemandCaltest)
	ON_BN_CLICKED(IDC_BUT_DEMAND_FACDEF, OnBnClickedButDemandFacdef)
	ON_BN_CLICKED(IDC_BUT_DEMAND_LABFEED, OnBnClickedButDemandLabfeed)
	ON_BN_CLICKED(IDC_BUT_DEMAND_PRNCON, OnBnClickedButDemandPrncon)
	ON_BN_CLICKED(IDC_BUT_BARCODE, OnBnClickedButBarcode)
	ON_BN_CLICKED(IDC_BUT_TEXT, OnBnClickedButText)
	ON_BN_CLICKED(IDC_BUT_IMAGE, OnBnClickedButImage)
	ON_BN_CLICKED(IDC_BUT_BOX, OnBnClickedButBox)
	ON_BN_CLICKED(IDC_BUT_LINE, OnBnClickedButLine)
	ON_BN_CLICKED(IDC_BUT_ENUM_USB, OnBnClickedButEnumUsb)
	ON_BN_CLICKED(IDC_BUT_ENUM_RS232, OnBnClickedButEnumRs232)
	ON_BN_CLICKED(IDC_BUT_SET_RS232, OnBnClickedButSetRs232)
	ON_BN_CLICKED(IDC_BUT_GETTING, OnBnClickedButGetting)
	ON_BN_CLICKED(IDC_BUT_PDF417, OnBnClickedButPdf417)
	ON_BN_CLICKED(IDC_BUT_DATAMATRIX, OnBnClickedButDatamatrix)
	ON_BN_CLICKED(IDC_BUT_MAXICODE, OnBnClickedButMaxicode)
	ON_BN_CLICKED(IDC_BUT_SOLVC_ABOUT, OnBnClickedButSolvcAbout)
	ON_BN_CLICKED(IDC_BUT_SENDCMD, OnBnClickedButSendcmd)
	ON_BN_CLICKED(IDC_BUT_SENDCMD2, OnBnClickedButSendcmd2)
	ON_BN_CLICKED(IDC_BUT_SENDFILE, OnBnClickedButSendfile)
	ON_BN_CLICKED(IDC_BUT_SENDFILE2, OnBnClickedButSendfile2)
	ON_BN_CLICKED(IDC_BUT_DEMAND_BARDRAWER, OnBnClickedButDemandBardrawer)
	ON_BN_CLICKED(IDC_BUTTON1, OnBnClickedButFormTest)
	ON_BN_CLICKED(IDC_BUT_ETHERNET, OnBnClickedButEthernet)
	ON_BN_CLICKED(IDC_BUT_LPTPORT, OnBnClickedButLptport)
	ON_BN_CLICKED(IDC_BUT_IMAGE2, OnBnClickedButImage2)
	ON_BN_CLICKED(IDC_BUT_TTF_ALIGN, OnBnClickedButTtfAlign)
	ON_BN_CLICKED(IDC_BUT_QRCODE, OnBnClickedButQrcode)
	ON_BN_CLICKED(IDC_BUT_PARAGRAPH, OnBnClickedButParagraph)
	ON_BN_CLICKED(IDC_BUTTON2, OnBnClickedCommandsParser)
	ON_BN_CLICKED(IDC_BUTTON3, &CSolution_VCDlg::OnBnClickedGetScaleData)
END_MESSAGE_MAP()


// CSolution_VCDlg message handlers

BOOL CSolution_VCDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Add "About..." menu item to system menu.

	// IDM_ABOUTBOX must be in the system command range.
	ASSERT((IDM_ABOUTBOX & 0xFFF0) == IDM_ABOUTBOX);
	ASSERT(IDM_ABOUTBOX < 0xF000);

	CMenu* pSysMenu = GetSystemMenu(FALSE);
	if (pSysMenu != NULL)
	{
		CString strAboutMenu;
		strAboutMenu.LoadString(IDS_ABOUTBOX);
		if (!strAboutMenu.IsEmpty())
		{
			pSysMenu->AppendMenu(MF_SEPARATOR);
			pSysMenu->AppendMenu(MF_STRING, IDM_ABOUTBOX, strAboutMenu);
		}
	}

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon

	// TODO: Add extra initialization here

	return TRUE;  // return TRUE  unless you set the focus to a control
}

void CSolution_VCDlg::OnSysCommand(UINT nID, LPARAM lParam)
{
	if ((nID & 0xFFF0) == IDM_ABOUTBOX)
	{
		CAboutDlg dlgAbout;
		dlgAbout.DoModal();
	}
	else
	{
		CDialog::OnSysCommand(nID, lParam);
	}
}

// If you add a minimize button to your dialog, you will need the code below
//  to draw the icon.  For MFC applications using the document/view model,
//  this is automatically done for you by the framework.

void CSolution_VCDlg::OnPaint()
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, reinterpret_cast<WPARAM>(dc.GetSafeHdc()), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// The system calls this function to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CSolution_VCDlg::OnQueryDragIcon()
{
	return static_cast<HCURSOR>(m_hIcon);
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Printing Functions
void CSolution_VCDlg::OnBnClickedButText()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4, 3, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;
	PrintText(2.0f, 1.5f, 0, 2, 1, 1, 0, 8, "AaBbCcDd"); // X=2.0, Y=1.5 (inches), No rotation, Font2, Hor Expand=1, Ver Expand=1, normal image
	PrintText(2.0f, 1.5f, 90, 2, 1, 1, 0, 8, "AaBbCcDd"); // X=2.0, Y=1.5 (inches), 90 rotation, Font2, Hor Expand=1, Ver Expand=1, normal image
	PrintText(2.0f, 1.5f, 180, 2, 1, 1, 0, 8, "AaBbCcDd"); // X=2.0, Y=1.5 (inches), 180 rotation, Font2, Hor Expand=1, Ver Expand=1, normal image
	PrintText(2.0f, 1.5f, 270, 2, 1, 1, 0, 8, "AaBbCcDd"); // X=2.0, Y=1.5 (inches), 270 rotation, Font2, Hor Expand=1, Ver Expand=1, normal image

	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButTruetypefont()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4, 3, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 0); // nSpeed=3, nDarkness=8, bDirectThermal=1;
	PrintTrueTypeFontA(2.0f, 1.5f, 12, -1, 0, 3, 0, 0, "Times New Roman", "AaBbCcDd"); // nFontH=12, nFontW=-1, nRotation=0, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintTrueTypeFontA(2.0f, 1.5f, 12, -1, 1, 3, 0, 0, "Times New Roman", "AaBbCcDd"); // nFontH=12, nFontW=-1, nRotation=1, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintTrueTypeFontW(2.0f, 1.5f, 12, -1, 2, 3, 0, 0, _T("Times New Roman"), _T("AaBbCcDd")); // nFontH=12, nFontW=-1, nRotation=2, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintTrueTypeFontW(2.0f, 1.5f, 12, -1, 3, 3, 0, 0, _T("Times New Roman"), _T("AaBbCcDd")); // nFontH=12, nFontW=-1, nRotation=3, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintBox(1.2f, 0.7f, 2, 2.8f, 2.35f);
	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButTtfAlign()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4, 3, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;
#if 1
	PrintTTF_AlignmentA(2.0f, 1.5f, 1.5, 2, 12, -1, 0, 3, 0, 0, "Times New Roman", "AaBbCcDd"); // nFontH=12, nFontW=-1, nRotation=0, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintTTF_AlignmentA(2.0f, 1.5f, 1.5, 2, 12, -1, 1, 3, 0, 0, "Times New Roman", "AaBbCcDd"); // nFontH=12, nFontW=-1, nRotation=1, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintTTF_AlignmentA(2.0f, 1.5f, 1.5, 2, 12, -1, 2, 3, 0, 0, "Times New Roman", "AaBbCcDd"); // nFontH=12, nFontW=-1, nRotation=2, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintTTF_AlignmentA(2.0f, 1.5f, 1.5, 2, 12, -1, 3, 3, 0, 0, "Times New Roman", "AaBbCcDd"); // nFontH=12, nFontW=-1, nRotation=3, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintBox(0.5f, 0.0f, 2, 3.5f, 3.0f);
	PrintBox(1.3f, 0.8f, 2, 2.7f, 2.2f);
#else
	PrintTTF_AlignmentW(2.0f, 1.5f, 1.5, 2, 12, -1, 0, 3, 1, 1, _T("Times New Roman"), _T("߷s~n")); // nFontH=12, nFontW=-1, nRotation=0, nStyle=3(Bold and Italic), bUnderline=1, bWhitOnBlack=1
	PrintTTF_AlignmentW(2.0f, 1.5f, 1.5, 2, 12, -1, 1, 3, 1, 1, _T("Times New Roman"), _T("߷s~n")); // nFontH=12, nFontW=-1, nRotation=1, nStyle=3(Bold and Italic), bUnderline=1, bWhitOnBlack=1
	PrintTTF_AlignmentW(2.0f, 1.5f, 1.5, 2, 12, -1, 2, 3, 1, 1, _T("Times New Roman"), _T("߷s~n")); // nFontH=12, nFontW=-1, nRotation=2, nStyle=3(Bold and Italic), bUnderline=1, bWhitOnBlack=1
	PrintTTF_AlignmentW(2.0f, 1.5f, 1.5, 2, 12, -1, 3, 3, 1, 1, _T("Times New Roman"), _T("߷s~n")); // nFontH=12, nFontW=-1, nRotation=3, nStyle=3(Bold and Italic), bUnderline=1, bWhitOnBlack=1
#endif
	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButParagraph()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4, 3, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;
#if 1
	PrintParagraphA(2.0f, 1.5f, 1.5, 2, 12, -1, 0, 3, 0, 0, "Times New Roman", "AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz"); // nFontH=12, nFontW=-1, nRotation=0, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintParagraphA(2.0f, 1.5f, 1.5, 2, 12, -1, 1, 3, 0, 0, "Times New Roman", "AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz"); // nFontH=12, nFontW=-1, nRotation=1, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintParagraphA(2.0f, 1.5f, 1.5, 2, 12, -1, 2, 3, 0, 0, "Times New Roman", "AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz"); // nFontH=12, nFontW=-1, nRotation=2, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintParagraphA(2.0f, 1.5f, 1.5, 2, 12, -1, 3, 3, 0, 0, "Times New Roman", "AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz"); // nFontH=12, nFontW=-1, nRotation=3, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=0
	PrintBox(0.55f, 0.0f, 2, 3.5f, 3.0f);
#else
	PrintParagraphW(2.0f, 1.5f, 1.5, 2, 12, -1, 0, 3, 0, 1, _T("Times New Roman"), _T("߮߷s~nAIEѦ~AѬO}uAHܡAjNμvTAUaűNQѤUCB")); // nFontH=12, nFontW=-1, nRotation=0, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=1
	PrintParagraphW(2.0f, 1.5f, 1.5, 2, 12, -1, 1, 3, 0, 1, _T("Times New Roman"), _T("߮߷s~nAIEѦ~AѬO}uAHܡAjNμvTAUaűNQѤUCB")); // nFontH=12, nFontW=-1, nRotation=1, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=1
	PrintParagraphW(2.0f, 1.5f, 1.5, 2, 12, -1, 2, 3, 0, 1, _T("Times New Roman"), _T("߮߷s~nAIEѦ~AѬO}uAHܡAjNμvTAUaűNQѤUCB")); // nFontH=12, nFontW=-1, nRotation=2, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=1
	PrintParagraphW(2.0f, 1.5f, 1.5, 2, 12, -1, 3, 3, 0, 1, _T("Times New Roman"), _T("߮߷s~nAIEѦ~AѬO}uAHܡAjNμvTAUaűNQѤUCB")); // nFontH=12, nFontW=-1, nRotation=3, nStyle=3(Bold and Italic), bUnderline=0, bWhitOnBlack=1
#endif
	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButBarcode()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	//if(PortOpen("c:\\output.txt") == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4.f, 3.0f, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;
	//SetAfterPrint (DEV_OPT_TEAR, 0); // Enable Tear-Off mode after printing.
	

	PrintBarcode(2.0f, 1.5f, 0.3f, 0, 1, 2, 4, TRUE, 5, "12345"); //fBarHeight=0.3, nRotation=0, nBarType=Code39, nNarrowBar=1, nWideBar=2, bHuman=Enabl
	PrintBarcode(2.0f, 1.5f, 0.3f, 1, 1, 2, 4, TRUE, 5, "12345"); //fBarHeight=0.3, nRotation=0, nBarType=Code39, nNarrowBar=1, nWideBar=2, bHuman=Enabl
	PrintBarcode(2.0f, 1.5f, 0.3f, 2, 1, 2, 4, TRUE, 5, "12345"); //fBarHeight=0.3, nRotation=0, nBarType=Code39, nNarrowBar=1, nWideBar=2, bHuman=Enabl
	PrintBarcode(2.0f, 1.5f, 0.3f, 3, 1, 2, 4, TRUE, 5, "12345"); //fBarHeight=0.3, nRotation=0, nBarType=Code39, nNarrowBar=1, nWideBar=2, bHuman=Enabl
	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButPdf417()
{
	int nCorrectionLevel = 1;
	BOOL bCompression = 0;
	int nModuleWidth = 2;
	int nBarHeight = 4;
	int nMaxColumns = 1;
	int nMaxRows = 10;
	int nTruncated = 0;
	int nDataLen = 5;
	char *pData = "12345";
	
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4.f, 3.0f, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;
	
	PrintPDF417(2.0f, 1.5f, 0, nCorrectionLevel, bCompression, nModuleWidth, nBarHeight, nMaxColumns, nMaxRows, nTruncated, nDataLen, pData);
	PrintPDF417(2.0f, 1.5f, 1, nCorrectionLevel, bCompression, nModuleWidth, nBarHeight, nMaxColumns, nMaxRows, nTruncated, nDataLen, pData);
	PrintPDF417(2.0f, 1.5f, 2, nCorrectionLevel, bCompression, nModuleWidth, nBarHeight, nMaxColumns, nMaxRows, nTruncated, nDataLen, pData);
	PrintPDF417(2.0f, 1.5f, 3, nCorrectionLevel, bCompression, nModuleWidth, nBarHeight, nMaxColumns, nMaxRows, nTruncated, nDataLen, pData);
	PrintBox(1.15f, 0.65f, 2, 2.9f, 2.4f);

	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButDatamatrix()
{
	int nColumns = 10;
	int nRows = 10;
	int nSquare = 4;
	BOOL bInverseImage = FALSE;
	int nDataLen = 5;
	char *pData = "12345";

	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4.f, 3.0f, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;	
	PrintDataMatrix(2.0f, 1.5f, 0, nColumns, nRows, nSquare, bInverseImage, nDataLen, pData);

	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButMaxicode()
{
	int nRotation = 0;
	int nMode = 0;
	int nDataLen;
	char *pData = "300,840,93065,1692,This is MaxiCode,but not MaxiCode formatted data";

	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4.f, 3.0f, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;
	
	nDataLen = (int)strlen(pData);
	PrintMaxiCode(0.8f, 0.8f, nRotation, nMode, nDataLen, pData);

	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButQrcode()
{
	int nErrorCorrection = 0;
	int nModel = 2;
	int nMaskNumber = 0;
	int nPixel = 4;
	int nDataLen = 5;
	char *pData = "12345";

	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4.f, 3.0f, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;
	
	PrintQRcode(2.0f, 1.5f, 0, nErrorCorrection, nModel, nMaskNumber, nPixel, nDataLen, pData);
	PrintQRcode(2.0f, 1.5f, 1, nErrorCorrection, nModel, nMaskNumber, nPixel, nDataLen, pData);
	PrintQRcode(2.0f, 1.5f, 2, nErrorCorrection, nModel, nMaskNumber, nPixel, nDataLen, pData);
	PrintQRcode(2.0f, 1.5f, 3, nErrorCorrection, nModel, nMaskNumber, nPixel, nDataLen, pData);
	PrintBox(1.49f, 0.99f, 2, 2.51f, 2.01f);

	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButImage()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4.f, 3.0f, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetPrinter(3, 8, 1); // nSpeed=3, nDarkness=8, bDirectThermal=1;

	PrintImage(2.0f, 1.5f, 1.0, 1.5, 0, 1, "TestImage.jpg"); // nWidth=-1(Original Size), nHeight=-1(Original Size), bErrorDiffusion=1
	PrintImage(2.0f, 1.5f, 1.0, 1.5, 1, 1, "TestImage.jpg"); // nWidth=-1(Original Size), nHeight=-1(Original Size), bErrorDiffusion=1
	PrintImage(2.0f, 1.5f, 1.0, 1.5, 2, 1, "TestImage.jpg"); // nWidth=-1(Original Size), nHeight=-1(Original Size), bErrorDiffusion=1
	PrintImage(2.0f, 1.5f, 1.0, 1.5, 3, 1, "TestImage.jpg"); // nWidth=-1(Original Size), nHeight=-1(Original Size), bErrorDiffusion=1
	PrintBox(0.55f, 0.05f, 2, 3.45f, 2.95f);

	//PrintImage(3.0f, 0.2f, 1.0f, 1.0f, 0, 0, "TestImage.jpg"); // nWidth=-1(Original Size), nHeight=-1(Original Size), bErrorDiffusion=1
	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButImage2()
{
	char acPortBuffer[40];
	
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port

	//===== First time to save and print image
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	SetMedia_LabelWithGaps(4.f, 3.0f, 0.16f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	// save image with the ID specified
	Image_Save(1.0f, 1.0f, 0, 0, "TestImage.jpg", "IMAGE_01"); // nWidth=-1(Original Size), nHeight=-1(Original Size), bErrorDiffusion=0

	// print image with the ID specified
	Image_Print(3.0f, 0.2f, "IMAGE_01");
	Image_Print(1.0f, 0.2f, "IMAGE_01");
	PrintBox(1.1f, 0.25f, 2, 3.9f, 1.2f);
	PrintLabel(1, 1, 0);
	
	PortClose();


	//===== Second time to print image wit ID-sting
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	// print image with the ID specified
	Image_Print(0.0f, 0.2f, "IMAGE_01");
	Image_Print(2.0f, 0.2f, "IMAGE_01");
	PrintBox(0.1f, 0.25f, 2, 2.9f, 1.2f);
	PrintLabel(1, 1, 0);

	// delete image with the ID specified
	Image_Delete("IMAGE_01");
	PortClose();

}

void CSolution_VCDlg::OnBnClickedButLine()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(0, 0); // dots
	PrintLine(50, 100, 200, 5, 0); // Black Line
	PrintLine(100, 50, 5, 200, 0); // Black Line
	PrintLine(150, 50, 5, 200, 1); // White Line
	PrintLine(200, 50, 5, 200, 2); // Exclusive OR Line
	PrintLabel(1, 1, 0);
	PortClose();
}

void CSolution_VCDlg::OnBnClickedButBox()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(1, 0); // inchs
	PrintBox(0.5f, 0.5f, 12, 1.0f, 1.0f); // (0.5, 0.5) to (1, 1) inch with 12 dots thickness
	PrintLabel(1, 1, 0);
	PortClose();
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Port Functions
void CSolution_VCDlg::OnBnClickedButEnumUsb()
{
	int nPortCount = PortEnumCount(0); // Get USB count
    char acPortBuffer[24];
	if(nPortCount > 0)
	{
		PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
		PortOpen(acPortBuffer);
		SetMeasurement(1, 0); // inchs
		PrintText(1.1f, 0.2f, 0, 1, 1, 1, 0, 14, "Print from USB");
		PrintLabel(1, 1, 0);
		PortClose();
	}
}

void CSolution_VCDlg::OnBnClickedButEthernet()
{
	int nPortCount = PortEnumCount(3); // Get Ethernet IP Address count
    char acPortBuffer[24];
	if(nPortCount > 0)
	{
		PortEnumGet(3, 0, acPortBuffer); // Get IP Address of number 0 of Ethernet
		PortOpen(acPortBuffer);
		//PortOpen("192.168.11.2");
		SetMeasurement(1, 0); // inchs
		PrintText(1.1f, 0.2f, 0, 1, 1, 1, 0, 16, "Print from Ethernet");
		PrintLabel(1, 1, 0);
		PortClose();
	}
}

void CSolution_VCDlg::OnBnClickedButLptport()
{
	int nPortCount = PortEnumCount(2); // Get LPT count
    char acPortBuffer[24];
	if(nPortCount > 0)
	{
		PortEnumGet(2, 0, acPortBuffer); // Get name of number 0 of LPT port
		PortOpen(acPortBuffer);
		SetMeasurement(1, 0); // inchs
		PrintText(1.1f, 0.2f, 0, 1, 1, 1, 0, 16, "Print from LPT");
		PrintLabel(1, 1, 0);
		PortClose();
	}
}

void CSolution_VCDlg::OnBnClickedButEnumRs232()
{
	int nPortCount = PortEnumCount(1); // Get RS232 count
    char acPortBuffer[24];
	if(nPortCount > 0)
	{
		PortEnumGet(1, 0, acPortBuffer); // Get name of number 1 of RS232 port
		PortSetupSerial(115200, 8, 0, 1, 1); // 115200 bps, 8 data-bits, no parity, 1 stop bit, hardware flowing control.
		PortOpen(acPortBuffer);		
		SetMeasurement(1, 0); // inchs
		PrintText(1.1f, 0.2f, 0, 1, 1, 1, 0, 16, "Print from RS232");
		PrintLabel(1, 1, 0);
		PortClose();
	}
}

void CSolution_VCDlg::OnBnClickedButSetRs232()
{
	PortSetupSerial(115200, 8, 0, 1, 1); // 115200 bps, 8 data-bits, no parity, 1 stop bit, hardware flowing control.
	PortOpen("COM1");
	SetMeasurement(1, 0); // inchs
	PrintText(1.1f, 0.2f, 0, 1, 1, 1, 0, 17, "Print from RS232");
	PrintLabel(1, 1, 0);
	PortClose();
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Demand Functions
void CSolution_VCDlg::OnBnClickedButDemandCaltest()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	DemandCalibrationTest(); // demand the printer to run a calibration test.
	PortClose();
	AfxMessageBox(_T("Finish DemandCalibrationTest"));
}

void CSolution_VCDlg::OnBnClickedButDemandFacdef()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	DemandFactoryDefaults(); // demand the printer to make itself to be factory defaults.
	PortClose();
	AfxMessageBox(_T("Finish DemandFactoryDefaults"));
}

void CSolution_VCDlg::OnBnClickedButDemandLabfeed()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	DemandLabelFeed(); // demand the printer to feed out a blank label.
	PortClose();
	AfxMessageBox(_T("Finish DemandLabelFeed"));
}

void CSolution_VCDlg::OnBnClickedButDemandPrncon()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	DemandPrintConfiguration(); // demand the printer to print out a label with printer configuration.
	PortClose();
	AfxMessageBox(_T("Finish DemandPrintConfiguration"));
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Functions
void CSolution_VCDlg::OnBnClickedButSettings()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	SetMeasurement(0, 0); // nMeasurement=0(Dots), 1(Inches), 2(Centimeters), 3(Millimeters); nResolution=0(Currecnt Set)
	SetMedia_Continuous(800.f, 600.f, 20.f); // W=4 inch, H=3Inch, StopOffset=0.1 inch;
	SetMedia_LabelWithGaps(800.f, 600.f, 32.f, 0); // W=4 inch, H=3Inch, GapLen=32 dots, GapOffset=0;
	SetMedia_LabelWithMarks(800.f, 600.f, 40.f, 0);
	SetPrinter(3, 10, 1); // nSpeed=3, nDarkness=10, bDirectThermal=1;
	SetReferencePoint(0, 0); // Set X and Y axis to 0 dot.
	SetTPH_YOffset(0); // Set Y offset of TPH to 0 dot.

	SetAfterPrint (DEV_OPT_TEAR, 0); // Enable Tear-Off mode after printing.
	SetFontCharacterSet(7, 0); // 7 Bit Data with USA character Set
	PrintLabel(0, 0, 0); // Only send data to printer without printing

	PortClose();

	AfxMessageBox(_T("Done"));
}

void CSolution_VCDlg::OnBnClickedButGetting()
{
	CString strTemp;

	//PortOpen("COM1"); // not for LPT port
	//PortSetupSerial(115200, 8, 0, 1, 1); // 115200 bps, 8 data-bits, no parity, 1 stop bit, hardware flowing control.

	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}
	
	//////////////////////////////////////////////////////////
	//'''' Get Printer Emulation
	if(GetEmulationType() == 100)
		AfxMessageBox(_T("PEPL Emulation"));
	else
		AfxMessageBox(_T("Can't get emulation from printer"));

	//////////////////////////////////////////////////////////
	//'''' Get Printer Firmware Version
	char acBuffer[80];
	GetFirmwareVersion(acBuffer);
	strTemp = acBuffer;
	AfxMessageBox(strTemp);

	//////////////////////////////////////////////////////////
	//'''' Get Printed Distance
	int nDistanceDots = GetPrintDistance(0); // Dots
	int nDistanceInchs = GetPrintDistance(1); // inchs
	int nDistanceCm = GetPrintDistance(2); // CentiMeters
	int nDistanceMm = GetPrintDistance(3); // Millimeters
	strTemp.Format(_T("%d dots, %d inchs, %d cm, %d mm, %d km"), nDistanceDots, nDistanceInchs, nDistanceCm, nDistanceMm, nDistanceCm/100/1000);
	AfxMessageBox(strTemp);

	//////////////////////////////////////////////////////////
	//'''' Get Current Status
	int nErrorCode = GetPrinterStatus();
	if( nErrorCode != 0)
		strTemp.Format(_T("Printr Status: Error Code %d"), nErrorCode);
	else
		strTemp = _T("Printr Status: Ready");
	AfxMessageBox(strTemp);

	//////////////////////////////////////////////////////////
	//'''' Get Printer Resolution
	int nResolution = GetResolution();
	strTemp.Format(_T("%d dpi"), nResolution);
	AfxMessageBox(strTemp);

	//////////////////////////////////////////////////////////
	//'''' Get Printer Serial Number
	if(GetSerialNumber(acBuffer) > 0)
	{
		strTemp = _T("Serial Number: ");
		strTemp += acBuffer;
		AfxMessageBox(strTemp);
	}
	else
		AfxMessageBox(_T("Can't get serial number"));


	//////////////////////////////////////////////////////////
	//'''' Get Reference Point
	int nAxisX = GetReferencePoint(0); // Get X axis in dot.
	int nAxisY = GetReferencePoint(1); // Get Y axis in dot.
	strTemp.Format(_T("X axis = %d,  Y axis = %d   (dots)"), nAxisX, nAxisY);
	AfxMessageBox(strTemp);

	//////////////////////////////////////////////////////////
	//'''' Get TPH Y Offset
	int nTphY = GetTPH_YOffset(); // Get TPH Y offset in dot.
	strTemp.Format(_T("TPH Y Offset = %d (dots)"), nTphY);
	AfxMessageBox(strTemp);



	PortClose();
}

void CSolution_VCDlg::OnBnClickedButDllAbout()
{
	double dbVersion = DllAbout(TRUE); // 1=display dialog, 0=only return version

	CString strVersion;

	strVersion.Format(_T("DLL Version: %g"), dbVersion);
	AfxMessageBox(strVersion);
}

void CSolution_VCDlg::OnBnClickedButSolvcAbout()
{
	AfxMessageBox(_T("Solution_VC Version: 1.9"));
}

void CSolution_VCDlg::OnBnClickedButSendcmd()
{
	char acData[] = "\r\nZT\r\nB200,200,0,3,1,2,60,B,\"12345\"\r\nP1\r\n";

	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	int nDataLen = (int)strlen(acData);
	if(nDataLen != SendCmd(nDataLen, (LPBYTE)acData))
		AfxMessageBox(_T("The data length is not correct."));

	PortClose();
}

void CSolution_VCDlg::OnBnClickedButSendcmd2()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	int nDataLen = SendCmd(-1, NULL);
	
	CString strMessage;
	strMessage.Format(_T("Data length = %d"), nDataLen);
	AfxMessageBox(strMessage);

	PortClose();
}

void CSolution_VCDlg::OnBnClickedButSendfile()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}

	int nDataLen = SendFileA("testcmd.txt");
	//int nDataLen = SendFileW(_T("testcmd.txt"));
	
	CString strMessage;
	strMessage.Format(_T("Data length = %d"), nDataLen);
	AfxMessageBox(strMessage);

	PortClose();
}

void CSolution_VCDlg::OnBnClickedButSendfile2()
{
	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	//if(PortOpen("\\\\TESTPC\\BarDrawe") == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}
	
	int nDataLen = SendFileA("open");
	//int nDataLen = SendFileW(_T("open"));
	
	CString strMessage;
	strMessage.Format(_T("Data length = %d"), nDataLen);
	AfxMessageBox(strMessage);

	PortClose();
}

void CSolution_VCDlg::OnBnClickedButDemandBardrawer()
{
	int nType = 1;
	BOOL nSaveInfos = TRUE;
	char* pstrFilePath = "Excel database.xls";
	char* pstrUserName = "Admin";
	char* pstrPassword = "";
	char* pstrTable = "Sheet1$";

	BarDrawer_DatabaseSet(nType, nSaveInfos, pstrFilePath, pstrUserName, pstrPassword, pstrTable);
	//BarDrawer_DatabaseSet(1 /*Excel*/, TRUE, "Excel database.xls", "Admin", "", "Sheet1$");
	BarDrawer_Launch("DLLTest.bdw");
	//BarDrawer_LaunchNew("Sample1.bdw");
	
}

void CSolution_VCDlg::OnBnClickedButFormTest()
{

#define FORM_NAME "TRUNCATION"
#define FORM_PARAMETER1 "FF12345678"
#define FORM_PARAMETER2 "RR87654321"

	char acPortBuffer[40];
	int nPortCount = PortEnumCount(0); // Get USB count
	PortEnumGet(0, 0, acPortBuffer); // Get name of number 0 of USB port
	if(PortOpen(acPortBuffer) == 0)
	//if(PortOpen("c:\\testfile.txt") == 0)
	{
		AfxMessageBox(_T("Can't open port!"));
		return;
	}
	

	//===== Send form file to printer
	if(!FormCheck("TRUNCATION"))
	{
		int nDataLen = FormSaveByFileA("Sample_Truncation_Form.prn");
		if(nDataLen == 0)
		{
			AfxMessageBox(_T("Can't open file!"));
			PortClose();
			return;
		}
	}
	

	//===== Send Parameter Data to printer
	FormExecute(FORM_NAME); // Send command to printer to execute form by form name "TRUNCATION".
	FormParameterData(FORM_PARAMETER1);
	FormParameterData(FORM_PARAMETER2);
	FormPrint(1,1);
	PortClose();


	AfxMessageBox(_T("--- Test End ---"));
}

void CSolution_VCDlg::OnBnClickedCommandsParser()
{
#if 0
	//CmdParserFileW(_T("C:\\Users\\Eric_Teng\\Documents\\LinePrintTest.txt"));
	//CmdParserFileW(_T("C:\\Documents and Settings\\Administrator\\My Documents\\Temp.txt"));
	CmdParserFileW(_T("open"));
#else
	CmdParserBufW(_T("PortOpen_USB(0);"));
	CmdParserBufW(_T("SetMeasurement(2, 203);"));
	CmdParserBufW(_T("SetMedia_Continuous(10.16, 0, 0);"));
	CmdParserBufW(_T("SetPrinter(3, 10, 1);"));
	CmdParserBufW(_T("SetAfterPrint(0, 1);"));
	CmdParserBufW(_T("LinePrint_Row_Set(0.4);"));
	CmdParserBufW(_T("LinePrint_Image_Print(1, 0, \"AVON.bmp\");"));
	CmdParserBufW(_T("LinePrint_TTF_Set(-14, 0, 0, 0, 0, 0, \"з\");"));
	CmdParserBufW(_T("LinePrint_TTF_Print(1, 0, 10.16, 1, \"ȥq,lop\");"));

	CmdParserBufA ("LinePrint_TTF_Print(1, 0.3, 0, 0, \"iq馩vG25H\");");
	CmdParserBufA ("LinePrint_TTF_Print(0, 6.5, 0, 0, \"q渹XG938569\");");
	CmdParserBufA ("LinePrint_TTF_Print(1, 0.3, 0, 0, \"-----------------------------------------------------------\");");
	CmdParserBufA ("LinePrint_TTF_Print(1, 0.3, 0, 0, \"ƶq ~W        ~s ؿ `p ʳfB Ƶ\");");

	CmdParserBufW(_T("PrintLabel(1, 1, 0);"));
	CmdParserBufW(_T("PortClose();"));
	//CmdParserBufW(_T("open"));
#endif
}

void CSolution_VCDlg::OnBnClickedGetScaleData()
{
	CString strTemp;
	double dbResult = GetScaleData(1, 1);

	strTemp.Format(_T("%g"), dbResult);
	AfxMessageBox(strTemp);
}
